==> pywfn-1.0.5-py3-none-any.whl: pywfn/data/__init__.py <==
from functools import lru_cache,cached_property

from itertools import product
from pywfn.base.basis import Basis
from pywfn.data.elements import Elements
import numpy as np


start=\
"""
欢迎使用 pywfn : 基于python的波函数分析工具
文档 https://www.xiaofei911.top/mkdocs/pywfn/
按q 即可退出程序，如无特殊提示，按 Enter 可返回上一级
按照提示输入编号即可轻松使用本程序
"""

Rhm=np.zeros(shape=(10,10))
Whm=np.zeros(shape=(10,10))

Rhm[ 0, 0] =  0E0
Rhm[ 1, 0] = -0.70710678118654752440E+00 
Rhm[ 1, 1] =  0.70710678118654752440E+00
Rhm[ 2, 0] = -1.22474487139158904910E+00
Rhm[ 2, 1] =  0E0
Rhm[ 2, 2] =  1.22474487139158904910E+00
Rhm[ 3, 0] = -1.65068012388578455588E+00
Rhm[ 3, 1] = -0.52464762327529031788E+00
Rhm[ 3, 2] =  0.52464762327529031788E+00
Rhm[ 3, 3] =  1.65068012388578455588E+00
Rhm[ 4, 0] = -2.02018287045608563293E+00
Rhm[ 4, 1] = -0.95857246461381850711E+00
Rhm[ 4, 2] =  0E0
Rhm[ 4, 3] =  0.95857246461381850711E+00
Rhm[ 4, 4] =  2.02018287045608563293E+00
Rhm[ 5, 0] = -2.35060497367449222283E+00
Rhm[ 5, 1] = -1.33584907401369694971E+00
Rhm[ 5, 2] = -0.43607741192761650868E+00
Rhm[ 5, 3] =  0.43607741192761650868E+00
Rhm[ 5, 4] =  1.33584907401369694971E+00
Rhm[ 5, 5] =  2.35060497367449222283E+00
Rhm[ 6, 0] = -2.65196135683523349245E+00
Rhm[ 6, 1] = -1.67355162876747144503E+00
Rhm[ 6, 2] = -0.81628788285896466304E+00
Rhm[ 6, 3] =  0E0
Rhm[ 6, 4] =  0.81628788285896466304E+00
Rhm[ 6, 5] =  1.67355162876747144503E+00
Rhm[ 6, 6] =  2.65196135683523349245E+00
Rhm[ 7, 0] = -2.93063742025724401922E+00
Rhm[ 7, 1] = -1.98165675669584292585E+00
Rhm[ 7, 2] = -1.15719371244678019472E+00
Rhm[ 7, 3] = -0.38118699020732211685E+00
Rhm[ 7, 4] =  0.38118699020732211685E+00
Rhm[ 7, 5] =  1.15719371244678019472E+00
Rhm[ 7, 6] =  1.98165675669584292585E+00
Rhm[ 7, 7] =  2.93063742025724401922E+00
Rhm[ 8, 0] = -3.19099320178152760723E+00
Rhm[ 8, 1] = -2.26658058453184311180E+00
Rhm[ 8, 2] = -1.46855328921666793167E+00
Rhm[ 8, 3] = -0.72355101875283757332E+00
Rhm[ 8, 4] =  0E0
Rhm[ 8, 5] =  0.72355101875283757332E+00
Rhm[ 8, 6] =  1.46855328921666793167E+00
Rhm[ 8, 7] =  2.26658058453184311180E+00
Rhm[ 8, 8] =  3.19099320178152760723E+00
Rhm[ 9, 0] = -3.43615911883773760333E+00
Rhm[ 9, 1] = -2.53273167423278979641E+00
Rhm[ 9, 2] = -1.75668364929988177345E+00
Rhm[ 9, 3] = -1.03661082978951365418E+00
Rhm[ 9, 4] = -0.34290132722370460879E+00
Rhm[ 9, 5] =  0.34290132722370460879E+00
Rhm[ 9, 6] =  1.03661082978951365418E+00
Rhm[ 9, 7] =  1.75668364929988177345E+00
Rhm[ 9, 8] =  2.53273167423278979641E+00
Rhm[ 9, 9] =  3.43615911883773760333E+00
Whm[ 0, 0] =  1.77245385090551602730E+00
Whm[ 1, 0] =  8.86226925452758013649E-01
Whm[ 1, 1] =  8.86226925452758013649E-01
Whm[ 2, 0] =  2.95408975150919337883E-01
Whm[ 2, 1] =  1.18163590060367735153E+00
Whm[ 2, 2] =  2.95408975150919337883E-01
Whm[ 3, 0] =  8.13128354472451771430E-02
Whm[ 3, 1] =  8.04914090005512836506E-01
Whm[ 3, 2] =  8.04914090005512836506E-01
Whm[ 3, 3] =  8.13128354472451771430E-02
Whm[ 4, 0] =  1.99532420590459132077E-02
Whm[ 4, 1] =  3.93619323152241159828E-01
Whm[ 4, 2] =  9.45308720482941881226E-01
Whm[ 4, 3] =  3.93619323152241159828E-01
Whm[ 4, 4] =  1.99532420590459132077E-02
Whm[ 5, 0] =  4.53000990550884564086E-03
Whm[ 5, 1] =  1.57067320322856643916E-01
Whm[ 5, 2] =  7.24629595224392524092E-01
Whm[ 5, 3] =  7.24629595224392524092E-01
Whm[ 5, 4] =  1.57067320322856643916E-01
Whm[ 5, 5] =  4.53000990550884564086E-03
Whm[ 6, 0] =  9.71781245099519154149E-04
Whm[ 6, 1] =  5.45155828191270305922E-02
Whm[ 6, 2] =  4.25607252610127800520E-01
Whm[ 6, 3] =  8.10264617556807326765E-01
Whm[ 6, 4] =  4.25607252610127800520E-01
Whm[ 6, 5] =  5.45155828191270305922E-02
Whm[ 6, 6] =  9.71781245099519154149E-04
Whm[ 7, 0] =  1.99604072211367619206E-04
Whm[ 7, 1] =  1.70779830074134754562E-02
Whm[ 7, 2] =  2.07802325814891879543E-01
Whm[ 7, 3] =  6.61147012558241291030E-01
Whm[ 7, 4] =  6.61147012558241291030E-01
Whm[ 7, 5] =  2.07802325814891879543E-01
Whm[ 7, 6] =  1.70779830074134754562E-02
Whm[ 7, 7] =  1.99604072211367619206E-04
Whm[ 8, 0] =  3.96069772632643819046E-05
Whm[ 8, 1] =  4.94362427553694721722E-03
Whm[ 8, 2] =  8.84745273943765732880E-02
Whm[ 8, 3] =  4.32651559002555750200E-01
Whm[ 8, 4] =  7.20235215606050957124E-01
Whm[ 8, 5] =  4.32651559002555750200E-01
Whm[ 8, 6] =  8.84745273943765732880E-02
Whm[ 8, 7] =  4.94362427553694721722E-03
Whm[ 8, 8] =  3.96069772632643819046E-05
Whm[ 9, 0] =  7.64043285523262062916E-06
Whm[ 9, 1] =  1.34364574678123269220E-03
Whm[ 9, 2] =  3.38743944554810631362E-02
Whm[ 9, 3] =  2.40138611082314686417E-01
Whm[ 9, 4] =  6.10862633735325798784E-01
Whm[ 9, 5] =  6.10862633735325798784E-01
Whm[ 9, 6] =  2.40138611082314686417E-01
Whm[ 9, 7] =  3.38743944554810631362E-02
Whm[ 9, 8] =  1.34364574678123269220E-03
Whm[ 9, 9] =  7.64043285523262062916E-06

==> pywfn-1.0.7-py3-none-any.whl: pywfn/data/__init__.py <==
from functools import lru_cache,cached_property

from itertools import product
from pywfn.base.basis import Basis
from pywfn.data.elements import Elements
import numpy as np


start=\
"""
欢迎使用 pywfn(1.0.7): 基于python的波函数分析工具
文档 https://www.xiaofei911.top/mkdocs/pywfn/
按 q 即可退出程序，按 Enter 可返回上一级
按照提示输入编号即可轻松使用本程序 (●ˇ∀ˇ●)
"""

Rhm=np.zeros(shape=(10,10))
Whm=np.zeros(shape=(10,10))

Rhm[ 0, 0] =  0E0
Rhm[ 1, 0] = -0.70710678118654752440E+00 
Rhm[ 1, 1] =  0.70710678118654752440E+00
Rhm[ 2, 0] = -1.22474487139158904910E+00
Rhm[ 2, 1] =  0E0
Rhm[ 2, 2] =  1.22474487139158904910E+00
Rhm[ 3, 0] = -1.65068012388578455588E+00
Rhm[ 3, 1] = -0.52464762327529031788E+00
Rhm[ 3, 2] =  0.52464762327529031788E+00
Rhm[ 3, 3] =  1.65068012388578455588E+00
Rhm[ 4, 0] = -2.02018287045608563293E+00
Rhm[ 4, 1] = -0.95857246461381850711E+00
Rhm[ 4, 2] =  0E0
Rhm[ 4, 3] =  0.95857246461381850711E+00
Rhm[ 4, 4] =  2.02018287045608563293E+00
Rhm[ 5, 0] = -2.35060497367449222283E+00
Rhm[ 5, 1] = -1.33584907401369694971E+00
Rhm[ 5, 2] = -0.43607741192761650868E+00
Rhm[ 5, 3] =  0.43607741192761650868E+00
Rhm[ 5, 4] =  1.33584907401369694971E+00
Rhm[ 5, 5] =  2.35060497367449222283E+00
Rhm[ 6, 0] = -2.65196135683523349245E+00
Rhm[ 6, 1] = -1.67355162876747144503E+00
Rhm[ 6, 2] = -0.81628788285896466304E+00
Rhm[ 6, 3] =  0E0
Rhm[ 6, 4] =  0.81628788285896466304E+00
Rhm[ 6, 5] =  1.67355162876747144503E+00
Rhm[ 6, 6] =  2.65196135683523349245E+00
Rhm[ 7, 0] = -2.93063742025724401922E+00
Rhm[ 7, 1] = -1.98165675669584292585E+00
Rhm[ 7, 2] = -1.15719371244678019472E+00
Rhm[ 7, 3] = -0.38118699020732211685E+00
Rhm[ 7, 4] =  0.38118699020732211685E+00
Rhm[ 7, 5] =  1.15719371244678019472E+00
Rhm[ 7, 6] =  1.98165675669584292585E+00
Rhm[ 7, 7] =  2.93063742025724401922E+00
Rhm[ 8, 0] = -3.19099320178152760723E+00
Rhm[ 8, 1] = -2.26658058453184311180E+00
Rhm[ 8, 2] = -1.46855328921666793167E+00
Rhm[ 8, 3] = -0.72355101875283757332E+00
Rhm[ 8, 4] =  0E0
Rhm[ 8, 5] =  0.72355101875283757332E+00
Rhm[ 8, 6] =  1.46855328921666793167E+00
Rhm[ 8, 7] =  2.26658058453184311180E+00
Rhm[ 8, 8] =  3.19099320178152760723E+00
Rhm[ 9, 0] = -3.43615911883773760333E+00
Rhm[ 9, 1] = -2.53273167423278979641E+00
Rhm[ 9, 2] = -1.75668364929988177345E+00
Rhm[ 9, 3] = -1.03661082978951365418E+00
Rhm[ 9, 4] = -0.34290132722370460879E+00
Rhm[ 9, 5] =  0.34290132722370460879E+00
Rhm[ 9, 6] =  1.03661082978951365418E+00
Rhm[ 9, 7] =  1.75668364929988177345E+00
Rhm[ 9, 8] =  2.53273167423278979641E+00
Rhm[ 9, 9] =  3.43615911883773760333E+00
Whm[ 0, 0] =  1.77245385090551602730E+00
Whm[ 1, 0] =  8.86226925452758013649E-01
Whm[ 1, 1] =  8.86226925452758013649E-01
Whm[ 2, 0] =  2.95408975150919337883E-01
Whm[ 2, 1] =  1.18163590060367735153E+00
Whm[ 2, 2] =  2.95408975150919337883E-01
Whm[ 3, 0] =  8.13128354472451771430E-02
Whm[ 3, 1] =  8.04914090005512836506E-01
Whm[ 3, 2] =  8.04914090005512836506E-01
Whm[ 3, 3] =  8.13128354472451771430E-02
Whm[ 4, 0] =  1.99532420590459132077E-02
Whm[ 4, 1] =  3.93619323152241159828E-01
Whm[ 4, 2] =  9.45308720482941881226E-01
Whm[ 4, 3] =  3.93619323152241159828E-01
Whm[ 4, 4] =  1.99532420590459132077E-02
Whm[ 5, 0] =  4.53000990550884564086E-03
Whm[ 5, 1] =  1.57067320322856643916E-01
Whm[ 5, 2] =  7.24629595224392524092E-01
Whm[ 5, 3] =  7.24629595224392524092E-01
Whm[ 5, 4] =  1.57067320322856643916E-01
Whm[ 5, 5] =  4.53000990550884564086E-03
Whm[ 6, 0] =  9.71781245099519154149E-04
Whm[ 6, 1] =  5.45155828191270305922E-02
Whm[ 6, 2] =  4.25607252610127800520E-01
Whm[ 6, 3] =  8.10264617556807326765E-01
Whm[ 6, 4] =  4.25607252610127800520E-01
Whm[ 6, 5] =  5.45155828191270305922E-02
Whm[ 6, 6] =  9.71781245099519154149E-04
Whm[ 7, 0] =  1.99604072211367619206E-04
Whm[ 7, 1] =  1.70779830074134754562E-02
Whm[ 7, 2] =  2.07802325814891879543E-01
Whm[ 7, 3] =  6.61147012558241291030E-01
Whm[ 7, 4] =  6.61147012558241291030E-01
Whm[ 7, 5] =  2.07802325814891879543E-01
Whm[ 7, 6] =  1.70779830074134754562E-02
Whm[ 7, 7] =  1.99604072211367619206E-04
Whm[ 8, 0] =  3.96069772632643819046E-05
Whm[ 8, 1] =  4.94362427553694721722E-03
Whm[ 8, 2] =  8.84745273943765732880E-02
Whm[ 8, 3] =  4.32651559002555750200E-01
Whm[ 8, 4] =  7.20235215606050957124E-01
Whm[ 8, 5] =  4.32651559002555750200E-01
Whm[ 8, 6] =  8.84745273943765732880E-02
Whm[ 8, 7] =  4.94362427553694721722E-03
Whm[ 8, 8] =  3.96069772632643819046E-05
Whm[ 9, 0] =  7.64043285523262062916E-06
Whm[ 9, 1] =  1.34364574678123269220E-03
Whm[ 9, 2] =  3.38743944554810631362E-02
Whm[ 9, 3] =  2.40138611082314686417E-01
Whm[ 9, 4] =  6.10862633735325798784E-01
Whm[ 9, 5] =  6.10862633735325798784E-01
Whm[ 9, 6] =  2.40138611082314686417E-01
Whm[ 9, 7] =  3.38743944554810631362E-02
Whm[ 9, 8] =  1.34364574678123269220E-03
Whm[ 9, 9] =  7.64043285523262062916E-06
